@@ -4,8 +4,8 @@
  * Author:    Michal Burda
  */
 
-#ifndef __RULEQUEUE_H__
-#define __RULEQUEUE_H__
+#ifndef __LFL__SEARCH__RULEQUEUE_H__
+#define __LFL__SEARCH__RULEQUEUE_H__
 
 
 #include <common.h>
@@ -14,6 +14,9 @@
 #include <queue>
 
 
+namespace lfl { namespace search {
+
+
 class RuleComparison {
 private:
     int m_statIndex;
@@ -44,4 +47,5 @@ public:
     { }
 };
 
+}}
 #endif
